==> hk2-api-1.6.5-sources.jar: org/glassfish/hk2/ContractLocator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.hk2;

import java.lang.annotation.Annotation;

/**
 * Created by IntelliJ IDEA.
 * User: dochez
 * Date: 5/3/11
 * Time: 10:15 AM
 * To change this template use File | Settings | File Templates.
 */
public interface ContractLocator<T> extends ServiceLocator<T> {
  
    ContractLocator<T> named(String name);

    ContractLocator<T> in(Scope scope);

    ContractLocator<T> annotatedWith(Class<? extends Annotation>... annotations);

    // TODO: this is still confusing, Providers provide access to "ComponentProviders" and our super class provides access to "Provider".
    // TODO: we need to reconcile the two, or perhaps consider renaming one of them.
    Providers<T> getProviders();
}

==> hk2-api-1.6.12-sources.jar: org/glassfish/hk2/ContractLocator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2;

import java.lang.annotation.Annotation;

/**
 * Provides a means to locate services in the HK2 services registry by
 * contract.
 * 
 * <p/>
 * ContractLocators are typically produced by calling one of the {@link
 * Locator} forContract() methods.
 * 
 * <p/>
 * This interface provides a builder like pattern that can be used to
 * refine the criteria for the {@link Providers} it will return.
 * 
 * @author Jerome Dochez
 * @author Jeff Trent
 * @author Mason Taube
 * 
 * @see Locator
 * @see Providers
 */
public interface ContractLocator<T> extends ServiceLocator<T> {

    /**
     * Qualify this ContractLocator to identify services that are named name.
     * 
     * @param name the name of the service
     * @return the same ContractLocator instance, now additionally qualified by name
     */
    ContractLocator<T> named(String name);

    /**
     * Qualify this ContractLocator to identify services that are scoped scope.
     * 
     * @param scope the scope of the service
     * @return the same ContractLocator instance, now additionally qualified by scope
     */
    ContractLocator<T> in(Scope scope);

    /**
     * Qualify this ContractLocator to identify services have the given annotations.
     * 
     * @param annotations the annotations that the service must have
     * @return the same ContractLocator instance, now additionally qualified by annotations
     */
    ContractLocator<T> annotatedWith(Class<? extends Annotation>... annotations);

}
